***************
Release History
***************

.. Changelog entries should follow this format:

   version (release date)
   ======================

   **section**

   - One-line description of change (link to Github issue/PR)

.. Changes should be organized in one of several sections:

   - Added
   - Changed
   - Deprecated
   - Removed
   - Fixed

0.2.0 (March 13, 2017)
======================

Initial release of TensorFlow-based NengoDL

0.1.0 (June 12, 2016)
=====================

Initial release of Lasagne-based NengoDL
